@@ -1,6 +1,5 @@
 /*
- Copyright (c) 2005, 2010, Oracle and/or its affiliates. All rights reserved.
- 
+  Copyright (c) 2005, 2014, Oracle and/or its affiliates. All rights reserved.
 
   The MySQL Connector/J is licensed under the terms of the GPLv2
   <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most MySQL Connectors.
@@ -20,26 +19,27 @@
   program; if not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth
   Floor, Boston, MA 02110-1301  USA
 
-*/
+ */
 
 package com.mysql.jdbc.exceptions;
 
-public class MySQLIntegrityConstraintViolationException extends
-		MySQLNonTransientException {
+public class MySQLIntegrityConstraintViolationException extends MySQLNonTransientException {
 
-	public MySQLIntegrityConstraintViolationException() {
-		super();
-	}
+    static final long serialVersionUID = -5528363270635808904L;
 
-	public MySQLIntegrityConstraintViolationException(String reason, String SQLState, int vendorCode) {
-		super(reason, SQLState, vendorCode);
-	}
+    public MySQLIntegrityConstraintViolationException() {
+        super();
+    }
 
-	public MySQLIntegrityConstraintViolationException(String reason, String SQLState) {
-		super(reason, SQLState);
-	}
+    public MySQLIntegrityConstraintViolationException(String reason, String SQLState, int vendorCode) {
+        super(reason, SQLState, vendorCode);
+    }
 
-	public MySQLIntegrityConstraintViolationException(String reason) {
-		super(reason);
-	}
+    public MySQLIntegrityConstraintViolationException(String reason, String SQLState) {
+        super(reason, SQLState);
+    }
+
+    public MySQLIntegrityConstraintViolationException(String reason) {
+        super(reason);
+    }
 }
