@@ -1,6 +1,5 @@
 /*
- Copyright (c) 2005, 2010, Oracle and/or its affiliates. All rights reserved.
- 
+  Copyright (c) 2005, 2014, Oracle and/or its affiliates. All rights reserved.
 
   The MySQL Connector/J is licensed under the terms of the GPLv2
   <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most MySQL Connectors.
@@ -20,26 +19,27 @@
   program; if not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth
   Floor, Boston, MA 02110-1301  USA
 
-*/
+ */
 
 package com.mysql.jdbc.exceptions;
 
 public class MySQLTransactionRollbackException extends MySQLTransientException implements DeadlockTimeoutRollbackMarker {
 
-	public MySQLTransactionRollbackException(String reason, String SQLState,
-			int vendorCode) {
-		super(reason, SQLState, vendorCode);
-	}
+    static final long serialVersionUID = 6034999468737801730L;
 
-	public MySQLTransactionRollbackException(String reason, String SQLState) {
-		super(reason, SQLState);
-	}
+    public MySQLTransactionRollbackException(String reason, String SQLState, int vendorCode) {
+        super(reason, SQLState, vendorCode);
+    }
 
-	public MySQLTransactionRollbackException(String reason) {
-		super(reason);
-	}
+    public MySQLTransactionRollbackException(String reason, String SQLState) {
+        super(reason, SQLState);
+    }
 
-	public MySQLTransactionRollbackException() {
-		super();
-	}
+    public MySQLTransactionRollbackException(String reason) {
+        super(reason);
+    }
+
+    public MySQLTransactionRollbackException() {
+        super();
+    }
 }
